@@ -28,6 +28,10 @@
 #include <QFile>
 #include <QDesktopServices>
 
+#if QT_VERSION >= 0x050000
+#include "myscroller.h"
+#endif
+
 using namespace Global;
 
 About::About(QWidget * parent, Qt::WindowFlags f)
@@ -36,6 +40,13 @@ About::About(QWidget * parent, Qt::WindowFlags f)
 	setupUi(this);
 	setWindowIcon( Images::icon("logo", 64) );
 
+#if QT_VERSION >= 0x050000
+	MyScroller::setScroller(info->viewport());
+	MyScroller::setScroller(contributions->viewport());
+	MyScroller::setScroller(translators->viewport());
+	MyScroller::setScroller(license->viewport());
+#endif
+
 	logo->setPixmap( QPixmap(":/default-theme/logo.png").scaledToHeight(64, Qt::SmoothTransformation) );
 	contrib_icon->setPixmap( Images::icon("contributors" ) );
 	translators_icon->setPixmap( Images::icon("translators" ) );
@@ -48,14 +59,12 @@ About::About(QWidget * parent, Qt::WindowFlags f)
 	info->setText(
 		"<b>SMPlayer</b> &copy; 2006-2016 Ricardo Villalba &lt;rvm@users.sourceforge.net&gt;<br><br>"
 		"<b>" + tr("Version: %1").arg(Version::printable()) + "</b>" +
+		(Version::is_unstable() ? "<br><i>" + tr("Development version") +"</i>" : "") +
 #if PORTABLE_APP
-                " (" + tr("Portable Edition") + ")" +
+		"<br>" + tr("Portable Edition") +
 #endif
-#ifdef EXPERIMENTAL
-        "<br>Experimental branch<br>"
-#endif
-        "<br>" +
-        tr("Using Qt %1 (compiled with Qt %2)").arg(qVersion()).arg(QT_VERSION_STR) + "<br>" +
+		"<p>" +
+		tr("Using Qt %1 (compiled with Qt %2)").arg(qVersion()).arg(QT_VERSION_STR) + "<br>" +
 		mplayer_version + "<br><br>" +
 		"<b>"+ tr("Links:") +"</b><br>"+
 		tr("Official website:") +" "+  link(URL_HOMEPAGE) +"<br>"+
