@@ -20,15 +20,28 @@
 #define BASEGUIPLUS_H
 
 #include "basegui.h"
+#include "widgetactions.h"
 #include <QSystemTrayIcon>
 #include <QPoint>
 #include "guiconfig.h"
 
+#define SCREENS_SUPPORT
+//#define DETACH_VIDEO_OPTION
+
+#define SEND_AUDIO_OPTION
+
+#ifdef SEND_AUDIO_OPTION
+#include "deviceinfo.h"
+#endif
+
 class QMenu;
 class PlaylistDock;
 
 class TimeSliderAction;
 class VolumeSliderAction;
+class TimeLabelAction;
+class InfoWindow;
+class GlobalShortcuts;
 
 class BaseGuiPlus : public BaseGui
 {
@@ -40,15 +53,25 @@ public:
 
 	virtual bool startHidden();
 
+#ifdef SCREENS_SUPPORT
+	/* virtual void toggleFullscreen(bool); */
+#endif
+
+public slots:
+#ifdef GLOBALSHORTCUTS
+	virtual void showPreferencesDialog();
+#endif
+
 protected:
 	virtual void retranslateStrings();
+	virtual void populateMainMenu();
 
 	void loadConfig();
 	void saveConfig();
 	void updateShowAllAct();
 
-    virtual void aboutToEnterFullscreen();
-    virtual void aboutToExitFullscreen();
+	virtual void aboutToEnterFullscreen();
+	virtual void aboutToExitFullscreen();
 	virtual void aboutToEnterCompactMode();
 	virtual void aboutToExitCompactMode();
 
@@ -57,6 +80,11 @@ protected:
 	// Functions for other GUI's
 	TimeSliderAction * createTimeSliderAction(QWidget * parent);
 	VolumeSliderAction * createVolumeSliderAction(QWidget * parent);
+	TimeLabelAction * createTimeLabelAction(TimeLabelAction::TimeLabelType type, QWidget * parent);
+
+#ifdef SCREENS_SUPPORT
+	bool isVideoDetached();
+#endif
 
 protected slots:
 	// Reimplemented methods
@@ -70,9 +98,6 @@ protected slots:
 	virtual void showAll(bool b);
 	virtual void showAll();
 	virtual void quit();
-#ifdef Q_OS_OS2
-	void trayAvailable();
-#endif
 
 #if DOCK_PLAYLIST
 	virtual void showPlaylist(bool b);
@@ -88,6 +113,24 @@ protected slots:
 	void shrinkWindow();
 #endif
 
+#ifdef SCREENS_SUPPORT
+	void updateSendToScreen();
+	void sendVideoToScreen(int screen);
+
+	void detachVideo(bool);
+
+	void showScreensInfo();
+#endif
+
+#ifdef SEND_AUDIO_OPTION
+	void updateSendAudioMenu();
+	void addListToSendAudioMenu(const DeviceList & audio_devices, const QString & prefix_name, const QString & prefix_device);
+	void sendAudioClicked();
+#endif
+
+#ifdef GLOBALSHORTCUTS
+	void updateGlobalShortcuts();
+#endif
 
 protected:
 	QSystemTrayIcon * tray;
@@ -97,6 +140,29 @@ protected:
 	MyAction * showTrayAct;
 	MyAction * showAllAct;
 
+#ifdef DETACH_VIDEO_OPTION
+	MyAction * detachVideoAct;
+#endif
+
+#ifdef SCREENS_SUPPORT
+	MyAction * showScreensInfoAct;
+	QMenu * sendToScreen_menu;
+	MyActionGroup * sendToScreenGroup;
+
+	InfoWindow * screens_info_window;
+	QLabel * detached_label;
+#endif
+
+#ifdef SEND_AUDIO_OPTION
+	DeviceList audio_devices;
+	QMenu * sendAudio_menu;
+	MyAction * sendAudioAct;
+#endif
+
+#ifdef GLOBALSHORTCUTS
+	GlobalShortcuts * global_shortcuts;
+#endif
+
 	// To save state
 	QPoint mainwindow_pos;
 	bool mainwindow_visible;
@@ -107,16 +173,15 @@ protected:
 	//QPoint infowindow_pos;
 	//bool infowindow_visible;
 
-   int widgets_size; // To be able to restore the original size after exiting from compact mode
+	int widgets_size; // To be able to restore the original size after exiting from compact mode
 
 #if DOCK_PLAYLIST
-    PlaylistDock * playlistdock;
+	PlaylistDock * playlistdock;
 	bool fullscreen_playlist_was_visible;
 	bool fullscreen_playlist_was_floating;
 	bool compact_playlist_was_visible;
 	bool ignore_playlist_events;
 #endif
-
 };
 
 #endif
