@@ -21,23 +21,94 @@
 #include <QProcess>
 #include <QFile>
 #include <QSettings>
+#include <QDebug>
 
 #ifdef Q_OS_WIN
 
+#define USE_DIRECTX
+
+#ifdef USE_DIRECTX
+#define DIRECTSOUND_VERSION 5
+#include <dsound.h>
+#include <ddraw.h>
+
+QStringList dsound_device_list;
+QStringList ddraw_device_list;
+
+BOOL CALLBACK DirectSoundEnum(LPGUID guid, LPCSTR desc, LPCSTR module, LPVOID context)
+{
+	Q_UNUSED(guid);
+	Q_UNUSED(module);
+	Q_UNUSED(context);
+
+	dsound_device_list << QString(desc);
+	return TRUE;
+}
+
+BOOL WINAPI DirectDrawEnum(GUID FAR *lpGUID, LPSTR lpDriverDescription, LPSTR lpDriverName, LPVOID lpContext, HMONITOR hm)
+{
+	Q_UNUSED(lpDriverName);
+	Q_UNUSED(lpContext);
+	Q_UNUSED(hm);
+
+	if (!lpGUID) {
+		ddraw_device_list << "Primary Display Adapter";
+	} else {
+		ddraw_device_list << QString(lpDriverDescription);
+	}
+	return TRUE;
+}
+
+
 DeviceList DeviceInfo::retrieveDevices(DeviceType type) {
 	qDebug("DeviceInfo::retrieveDevices: %d", type);
-	
+
+	DeviceList l;
+
+	dsound_device_list.clear();
+	ddraw_device_list.clear();
+
+	if (type == Sound) {
+		DirectSoundEnumerateA(DirectSoundEnum, NULL);
+		for (int n = 0; n < dsound_device_list.count(); n++) {
+			QString desc = dsound_device_list[n];
+			qDebug() << "DeviceInfo::retrieveDevices: audio:" << n << desc;
+			l.append( DeviceData(n, desc) );
+		}
+	}
+	else
+	if (type == Display) {
+		DirectDrawEnumerateExA(DirectDrawEnum, NULL, DDENUM_ATTACHEDSECONDARYDEVICES);
+		for (int n = 0; n < ddraw_device_list.count(); n++) {
+			QString desc = ddraw_device_list[n];
+			qDebug() << "DeviceInfo::retrieveDevices: display:" << n << desc;
+			l.append( DeviceData(n, desc) );
+		}
+	}
+
+	return l;
+}
+
+#else
+
+DeviceList DeviceInfo::retrieveDevices(DeviceType type) {
+	qDebug("DeviceInfo::retrieveDevices: %d", type);
+
+	DeviceList l;
+
+	#ifdef CACHE_DEVICE_INFO
 	QString inifile = Paths::configPath() + "/device_info.ini";
 	QSettings set(inifile, QSettings::IniFormat);
-	QString section_name = "display_devices";
-	if (type == Sound) section_name = "dsound_devices";
-	
+	QString section_name = "display-devices";
+	if (type == Sound) section_name = "dsound-devices";
+
 	// Check if we already have the list stored in the INI file
-	DeviceList l = loadList(&set, section_name);
+	l = loadList(&set, section_name);
 	if (l.count() > 0) return l;
-	
+	#endif
+
 	QRegExp rx_device("^(\\d+): (.*)");
-	
+
 	if (QFile::exists("dxlist.exe")) {
 		QProcess p;
 		p.setProcessChannelMode( QProcess::MergedChannels );
@@ -59,11 +130,14 @@ DeviceList DeviceInfo::retrieveDevices(DeviceType type) {
 			}
 		}
 	}
-	
+
+	#ifdef CACHE_DEVICE_INFO
 	saveList(&set, section_name, l);
-	
+	#endif
+
 	return l;
 }
+#endif
 
 DeviceList DeviceInfo::dsoundDevices() { 
 	return retrieveDevices(Sound);
@@ -75,15 +149,66 @@ DeviceList DeviceInfo::displayDevices() {
 
 #else
 
+// Linux
+
+#if USE_PULSEAUDIO_DEVICES
+DeviceList DeviceInfo::paDevices() {
+	qDebug("DeviceInfo::paDevices");
+
+	static DeviceList l;
+	if (!l.isEmpty()) return l;
+
+	QRegExp rx_index("(.*)index: (\\d+)");
+	QRegExp rx_name("(.*)name: (.*)");
+
+	QProcess p;
+	p.setProcessChannelMode( QProcess::MergedChannels );
+	QStringList env = QProcess::systemEnvironment();
+	env << "LC_ALL=C";
+	p.setEnvironment(env);
+	p.start("pacmd list-sinks");
+
+	int index = -1;
+	QString name;
+
+	if (p.waitForFinished()) {
+		QByteArray line;
+		while (p.canReadLine()) {
+			line = p.readLine().trimmed();
+			//qDebug() << "DeviceInfo::paDevices:" << line;
+			if (rx_index.indexIn(line) > -1 ) {
+				index = rx_index.cap(2).toInt();
+				qDebug() << "DeviceInfo::paDevices: index:" << index;
+			}
+			if (rx_name.indexIn(line) > -1 ) {
+				name = rx_name.cap(2);
+				qDebug() << "DeviceInfo::paDevices: name:" << name;
+				if (index != -1) {
+					l.append( DeviceData(index, name) );
+					index = -1;
+				}
+			}
+		}
+	}
+
+	return l;
+}
+#endif // USE_PULSEAUDIO_DEVICES
+
+#if USE_ALSA_DEVICES
 DeviceList DeviceInfo::alsaDevices() {
 	qDebug("DeviceInfo::alsaDevices");
 
+	DeviceList l;
+
+	#ifdef CACHE_DEVICE_INFO
 	QString inifile = Paths::configPath() + "/device_info.ini";
 	QSettings set(inifile, QSettings::IniFormat);
 
 	// Check if we already have the list stored in the INI file
-	DeviceList l = loadList(&set, "alsa_devices");
+	l = loadList(&set, "alsa-devices");
 	if (l.count() > 0) return l;
+	#endif
 
 	QRegExp rx_device("^card\\s([0-9]+).*\\[(.*)\\],\\sdevice\\s([0-9]+):");
 
@@ -110,20 +235,28 @@ DeviceList DeviceInfo::alsaDevices() {
 		qDebug("DeviceInfo::alsaDevices: could not start aplay, error %d", p.error());
 	}
 
-	saveList(&set, "alsa_devices", l);
+	#ifdef CACHE_DEVICE_INFO
+	saveList(&set, "alsa-devices", l);
+	#endif
 
 	return l;
 }
+#endif
 
+#ifdef USE_XV_ADAPTORS
 DeviceList DeviceInfo::xvAdaptors() {
 	qDebug("DeviceInfo::xvAdaptors");
 
+	DeviceList l;
+
+	#ifdef CACHE_DEVICE_INFO
 	QString inifile = Paths::configPath() + "/device_info.ini";
 	QSettings set(inifile, QSettings::IniFormat);
 
 	// Check if we already have the list stored in the INI file
-	DeviceList l = loadList(&set, "xv_adaptors");
+	l = loadList(&set, "xv-adaptors");
 	if (l.count() > 0) return l;
+	#endif
 
 	QRegExp rx_device("^.*Adaptor #([0-9]+): \"(.*)\"");
 
@@ -148,19 +281,22 @@ DeviceList DeviceInfo::xvAdaptors() {
 		qDebug("DeviceInfo::xvAdaptors: could not start xvinfo, error %d", p.error());
 	}
 
-	saveList(&set, "xv_adaptors", l);
+	#ifdef CACHE_DEVICE_INFO
+	saveList(&set, "xv-adaptors", l);
+	#endif
 
 	return l;
 }
-
+#endif
 #endif
 
+#ifdef CACHE_DEVICE_INFO
 void DeviceInfo::saveList(QSettings * set, const QString & section_name, const DeviceList & list) {
 	set->beginWriteArray(section_name);
 	for (int i = 0; i < list.count(); ++i) {
 		set->setArrayIndex(i);
 		set->setValue("ID", list.at(i).ID());
-		set->setValue("password", list.at(i).desc());
+		set->setValue("description", list.at(i).desc());
 	}
 	set->endArray();
 }
@@ -172,7 +308,7 @@ DeviceList DeviceInfo::loadList(QSettings * set, const QString & section_name) {
 	for (int i = 0; i < count; ++i) {
 		set->setArrayIndex(i);
 		QVariant id = set->value("ID");
-		QString desc = set->value("password", "").toString();
+		QString desc = set->value("description", "").toString();
 		l.append(DeviceData(id, desc));
 	}
 
@@ -180,3 +316,4 @@ DeviceList DeviceInfo::loadList(QSettings * set, const QString & section_name) {
 
 	return l;
 }
+#endif
