@@ -29,11 +29,11 @@ public:
 	FileSettingsBase(QString directory) { output_directory = directory; };
 	virtual ~FileSettingsBase() {};
 
-	virtual bool existSettingsFor(QString filename) = 0;
+	virtual bool existSettingsFor(QString filename, int type) = 0;
 
-	virtual void loadSettingsFor(QString filename, MediaSettings & mset, int player) = 0;
+	virtual void loadSettingsFor(QString filename, int type, MediaSettings & mset, int player) = 0;
 
-	virtual void saveSettingsFor(QString filename, MediaSettings & mset, int player) = 0;
+	virtual void saveSettingsFor(QString filename, int type, MediaSettings & mset, int player) = 0;
 
 protected:
 	QString output_directory;
