@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _LANGUAGES_H_
-#define _LANGUAGES_H_
+#ifndef LANGUAGES_H
+#define LANGUAGES_H
 
 #include <QObject>
 #include <QMap>
@@ -38,6 +38,8 @@ public:
 	static QMap<QString,QString> translations();
 
 	static QMap<QString,QString> encodings();
+
+	static QMap<QString,QString> enca();
 };
 
 #endif
