@@ -27,6 +27,10 @@
 
 #include "images.h"
 
+#if QT_VERSION >= 0x050000
+#include "myscroller.h"
+#endif
+
 LogWindow::LogWindow( QWidget* parent )
 	: QWidget(parent, Qt::Window ) 
 {
@@ -34,6 +38,10 @@ LogWindow::LogWindow( QWidget* parent )
 
 	browser->setFont( QFont("fixed") );
 
+#if QT_VERSION >= 0x050000
+	MyScroller::setScroller(browser);
+#endif
+
 	retranslateStrings();
 }
 
