@@ -28,6 +28,8 @@
 #include "config.h"
 #include "audioequalizerlist.h"
 
+//#define MSET_USE_STARTING_TIME
+
 class QSettings;
 
 class MediaSettings {
@@ -141,10 +143,12 @@ public:
 	QMap<int, QString> bookmarks;
 #endif
 
+#ifdef MSET_USE_STARTING_TIME
 	// This a property of the video and it should be
-    // in mediadata, but we have to save it to preserve 
+	// in mediadata, but we have to save it to preserve 
 	// this data among restarts.
 	double starting_time; // Some videos don't start at 0
+#endif
 
 	//! The codec of the video is ffh264 and it's high definition
 	bool is264andHD;
@@ -184,10 +188,8 @@ public:
 
 	void list();
 
-#ifndef NO_USE_INI_FILES
 	void save(QSettings * set, int player_id);
 	void load(QSettings * set, int player_id);
-#endif
 };
 
 #endif
