@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,15 +30,23 @@ using namespace Global;
 
 #define TOO_CHAPTERS_WORKAROUND
 
-MplayerProcess::MplayerProcess(QObject * parent) : MyProcess(parent) 
-{
+MplayerProcess::MplayerProcess(QObject * parent)
+	: PlayerProcess(parent)
+	, notified_mplayer_is_running(false)
+	, received_end_of_file(false)
+	, last_sub_id(-1)
+	, mplayer_svn(-1) // Not found yet
 #if NOTIFY_SUB_CHANGES
-	qRegisterMetaType<SubTracks>("SubTracks");
+	, subtitle_info_received(false)
+	, subtitle_info_changed(false)
 #endif
-
 #if NOTIFY_AUDIO_CHANGES
-	qRegisterMetaType<Tracks>("Tracks");
+	, audio_info_changed(false)
 #endif
+	, dvd_current_title(-1)
+	, br_current_title(-1)
+{
+	player_id = PlayerID::MPLAYER;
 
 	connect( this, SIGNAL(lineAvailable(QByteArray)),
 			 this, SLOT(parseLine(QByteArray)) );
@@ -48,10 +56,6 @@ MplayerProcess::MplayerProcess(QObject * parent) : MyProcess(parent)
 
 	connect( this, SIGNAL(error(QProcess::ProcessError)),
              this, SLOT(gotError(QProcess::ProcessError)) );
-
-	notified_mplayer_is_running = false;
-	last_sub_id = -1;
-	mplayer_svn = -1; // Not found yet
 }
 
 MplayerProcess::~MplayerProcess() {
@@ -80,77 +84,9 @@ bool MplayerProcess::start() {
 
 	MyProcess::start();
 
-#if !defined(Q_OS_OS2)
 	return waitForStarted();
-#else
-	bool r = waitForStarted();
-	if (r) {
-		pidMP = QProcess::pid();
-		qDebug("MPlayer PID %i", pidMP);
-		MPpipeOpen();
-	}
-	return r;
-#endif
 }
 
-void MplayerProcess::writeToStdin(QString text) {
-	if (isRunning()) {
-		//qDebug("MplayerProcess::writeToStdin");
-#if !defined(Q_OS_OS2)
-		#ifdef Q_OS_WIN
-		write( text.toUtf8() + "\n");
-		#else
-		write( text.toLocal8Bit() + "\n");
-		#endif
-#else
-		MPpipeWrite( text.toLocal8Bit() + "\n");
-#endif
-	} else {
-		qWarning("MplayerProcess::writeToStdin: process not running");
-	}
-#ifdef Q_OS_OS2
-	if (text == "quit" || text == "quit\n") {
-		MPpipeClose();
-	}
-#endif
-}
-
-#ifdef Q_OS_OS2
-void MplayerProcess::MPpipeOpen() {
-	char szPipeName[ 100 ];
-	sprintf( szPipeName, "\\PIPE\\MPLAYER\\%x", pidMP );
-	DosCreateNPipe( szPipeName, &hpipe, NP_ACCESS_DUPLEX, 1, 1024, 1024, 0 );
-}
-
-void MplayerProcess::MPpipeClose( void ) {
-	DosClose( hpipe );
-}
-
-void MplayerProcess::MPpipeWrite( const QByteArray text ) {
-	// MPlayer quitted ?
-	if ( !isRunning() )
-		return;
-
-// as things could hang when pipe communication is done direct here, i do a seperate thread for it
-	pipeThread = new PipeThread(text, hpipe);
-    
-	pipeThread->start();
-	while (!pipeThread->isRunning() && !pipeThread->isFinished()) {
-		qDebug("we sleep");
-		DosSleep(10);
-	}
-// we wait for max 2 seconds for the thread to be ended (we to this with max 20 loops)
-	int count = 0;
-	while (!pipeThread->wait(100) && count < 20) {
-		count ++;
-	}
-	if (count >= 20) {
-		pipeThread->terminate();
-		qDebug("pipe communication terminated");
-	}
-	delete pipeThread;
-}
-#endif
 
 static QRegExp rx_av("^[AV]: *([0-9,:.-]+)");
 static QRegExp rx_frame("^[AV]:.* (\\d+)\\/.\\d+");// [0-9,.]+");
@@ -313,6 +249,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 		//if (line.startsWith("MPlayer 1.0rc1")) line = "MPlayer 2:1.0~rc1-0ubuntu13.1 (C) 2000-2006 MPlayer Team";
 		//if (line.startsWith("MPlayer2")) line = "mplayer2 d0305da (C) 2000-2012 MPlayer & mplayer2 teams";
 		//if (line.startsWith("MPlayer SVN")) line = "MPlayer svn r34540 (Ubuntu), built with gcc-4.6 (C) 2000-2012 MPlayer Team";
+		//if (line.startsWith("MPlayer SVN")) line = "MPlayer 1.2-4.8 (C) 2000-2015 MPlayer Team";
 
 		// Emulates unknown version
 		//if (line.startsWith("MPlayer SVN")) line = "MPlayer lalksklsjjakksja";
@@ -436,7 +373,7 @@ void MplayerProcess::parseLine(QByteArray ba) {
 				else
 					audios.addLang(ID, lang);
 			} else {
-				qDebug("MplayerProcess::parseLine: audio %d exists, modifing it", ID);
+				qDebug("MplayerProcess::parseLine: audio %d exists, modifying it", ID);
 
 				if (t == "NAME") {
 					//qDebug("MplayerProcess::parseLine: name of audio %d: %s", ID, audios.itemAt(idx).name().toUtf8().constData());
@@ -926,31 +863,5 @@ void MplayerProcess::gotError(QProcess::ProcessError error) {
 	qDebug("MplayerProcess::gotError: %d", (int) error);
 }
 
-#ifdef Q_OS_OS2
-PipeThread::PipeThread(const QByteArray t, const HPIPE pipe) {
-	text = t;
-	hpipe = pipe;
-}
-
-PipeThread::~PipeThread() {
-}
-
-void PipeThread::run() {
-	ULONG cbActual;
-	APIRET rc = NO_ERROR; 
-
-	rc = DosConnectNPipe( hpipe );
-	if (rc != NO_ERROR) 
-		return;
-
-//	qDebug("pipe connected");    
-	DosWrite( hpipe, text.data(), strlen( text.data() ), &cbActual );
-
-	// Wait for ACK
-	DosRead( hpipe, &cbActual, sizeof( ULONG ), &cbActual );
-	DosDisConnectNPipe( hpipe );
-	return;
-}
-#endif
-
+#include "mplayeroptions.cpp"
 #include "moc_mplayerprocess.cpp"
