@@ -23,6 +23,8 @@
 #include "playerprocess.h"
 #include "config.h"
 
+#define OSD_WITH_TIMER
+
 class QStringList;
 
 class MPVProcess : public PlayerProcess
@@ -123,6 +125,10 @@ protected:
 	void addVFIfAvailable(const QString & vf, const QString & value = QString::null);
 	void messageFilterNotSupported(const QString & filter_name);
 
+#ifdef OSD_WITH_TIMER
+	void toggleInfoOnOSD();
+#endif
+
 protected slots:
 	void parseLine(QByteArray ba);
 	void processFinished(int exitCode, QProcess::ExitStatus exitStatus);
@@ -130,6 +136,10 @@ protected slots:
 	void requestChapterInfo();
 	void requestBitrateInfo();
 
+#ifdef OSD_WITH_TIMER
+	void displayInfoOnOSD();
+#endif
+
 protected:
 #if NOTIFY_AUDIO_CHANGES
 	void updateAudioTrack(int ID, const QString & name, const QString & lang);
@@ -138,6 +148,29 @@ protected:
 	void updateSubtitleTrack(int ID, const QString & name, const QString & lang);
 #endif
 
+private:
+	#if 0
+	// For some reason lupdate doesn't get the translations from mpvoptions.cpp
+	void translations() {
+		QString s = tr("the '%1' filter is not supported by mpv");
+		s = tr("File:");
+		s = tr("Video:");
+		s = tr("Resolution:");
+		s = tr("Frames per second:");
+		s = tr("Estimated:");
+		s = tr("Aspect Ratio:");
+		s = tr("Bitrate:");
+		s = tr("Dropped frames:");
+		s = tr("Audio:");
+		s = tr("Bitrate:");
+		s = tr("Sample Rate:");
+		s = tr("Channels:");
+		s = tr("Audio/video synchronization:");
+		s = tr("Cache fill:");
+		s = tr("Used cache:");
+	}
+	#endif
+
 private:
 	bool notified_mplayer_is_running;
 	bool notified_pause;
@@ -180,6 +213,10 @@ private:
 #ifdef CAPTURE_STREAM
 	bool capturing;
 #endif
+
+#ifdef OSD_WITH_TIMER
+	QTimer * osd_timer;
+#endif
 };
 
 #endif
