@@ -236,6 +236,7 @@ Playlist::Playlist(QWidget * parent, Qt::WindowFlags f)
 	, save_playlist_in_config(true)
 	, play_files_from_start(true)
 	, row_spacing(-1) // Default height
+	, start_play_on_load(true)
 	, automatically_play_next(true)
 	, ignore_player_errors(false)
 	, change_name(true)
@@ -327,12 +328,30 @@ void Playlist::setConfigPath(const QString & config_path) {
 	}
 }
 
+void Playlist::updateWindowTitle() {
+	QString title;
+
+	title = playlist_filename;
+	if (title.isEmpty()) title = tr("Untitled playlist");
+	if (modified) title += " (*)";
+
+	qDebug() << "Playlist::updateWindowTitle:" << title;
+
+	setWindowTitle(title);
+	emit windowTitleChanged(title);
+}
+
+void Playlist::setPlaylistFilename(const QString & f) {
+	playlist_filename = f;
+	updateWindowTitle();
+}
 
 void Playlist::setModified(bool mod) {
 	qDebug("Playlist::setModified: %d", mod);
 
 	modified = mod;
 	emit modifiedChanged(modified);
+	updateWindowTitle();
 }
 
 void Playlist::createTable() {
@@ -384,6 +403,7 @@ void Playlist::createTable() {
 //	listView->horizontalHeader()->setResizeMode(COL_FILENAME, QHeaderView::Interactive);
 #endif
 	listView->horizontalHeader()->setStretchLastSection(true);
+	listView->horizontalHeader()->setSortIndicator(0, Qt::AscendingOrder);
 
 	/*
 	listView->horizontalHeader()->setResizeMode(COL_TIME, QHeaderView::ResizeToContents);
@@ -415,7 +435,10 @@ void Playlist::createActions() {
 #endif
 
 	saveAct = new MyAction(this, "pl_save", false);
-	connect( saveAct, SIGNAL(triggered()), this, SLOT(save()) );
+	connect( saveAct, SIGNAL(triggered()), this, SLOT(saveCurrentPlaylist()) );
+
+	saveAsAct = new MyAction(this, "pl_save_as", false);
+	connect( saveAsAct, SIGNAL(triggered()), this, SLOT(save()) );
 
 	playAct = new MyAction(this, "pl_play", false);
 	connect( playAct, SIGNAL(triggered()), this, SLOT(playCurrent()) );
@@ -496,12 +519,26 @@ void Playlist::createToolbar() {
 	toolbar2->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
 #endif
 
+/*
 	toolbar->addAction(openAct);
 #ifdef PLAYLIST_DOWNLOAD
 	toolbar->addAction(openUrlAct);
 #endif
 	toolbar->addAction(saveAct);;
 	toolbar->addSeparator();
+*/
+
+	file_menu = new QMenu(this);
+	file_menu->addAction(openAct);
+	file_menu->addAction(saveAct);
+	file_menu->addAction(saveAsAct);
+#ifdef PLAYLIST_DOWNLOAD
+	file_menu->addAction(openUrlAct);
+#endif
+
+	file_button = new QToolButton(this);
+	file_button->setMenu(file_menu);
+	file_button->setPopupMode(QToolButton::InstantPopup);
 
 	add_menu = new QMenu( this );
 	add_menu->addAction(addCurrentAct);
@@ -529,6 +566,8 @@ void Playlist::createToolbar() {
 	loading_label->setMovie(animation);
 #endif
 
+	toolbar->addWidget(file_button);
+	toolbar->addSeparator();
 	toolbar->addWidget(add_button);
 	toolbar->addWidget(remove_button);
 
@@ -584,12 +623,13 @@ void Playlist::createToolbar() {
 void Playlist::retranslateStrings() {
 	table->setHorizontalHeaderLabels(QStringList() << " " << tr("Name") << tr("Length") << tr("Filename / URL") );
 
-	openAct->change( Images::icon("open"), tr("&Load") );
+	openAct->change( Images::icon("open"), tr("&Load...") );
 #ifdef PLAYLIST_DOWNLOAD
-	openUrlAct->change( Images::icon("url"), tr("&Open URL") );
+	openUrlAct->change( Images::icon("url"), tr("Load playlist from &URL...") );
 	openUrlAct->setToolTip(tr("Download playlist from URL"));
 #endif
 	saveAct->change( Images::icon("save"), tr("&Save") );
+	saveAsAct->change( Images::icon("save"), tr("Save &as...") );
 
 	playAct->change( tr("&Play") );
 
@@ -629,6 +669,8 @@ void Playlist::retranslateStrings() {
 	editAct->change( tr("&Edit") );
 
 	// Tool buttons
+	file_button->setIcon(Images::icon("open")); // FIXME: change icon
+	file_button->setToolTip(tr("Load/Save"));
 	add_button->setIcon( Images::icon("plus") );
 	add_button->setToolTip( tr("Add...") );
 	remove_button->setIcon( Images::icon("minus") );
@@ -641,7 +683,7 @@ void Playlist::retranslateStrings() {
 
 	// Icon
 	setWindowIcon( Images::icon("logo", 64) );
-	setWindowTitle( tr( "SMPlayer - Playlist" ) );
+	//setWindowTitle( tr( "SMPlayer - Playlist" ) );
 }
 
 void Playlist::list() {
@@ -721,7 +763,7 @@ int Playlist::count() {
 }
 
 bool Playlist::isEmpty() {
-	return (table->rowCount() > 0);
+	return (table->rowCount() == 0);
 }
 
 bool Playlist::existsItem(int row) {
@@ -895,6 +937,7 @@ void Playlist::load_m3u(QString file, M3UFormat format) {
 						filename = playlist_path + "/" + filename;
 					}
 				}
+				name.replace("&#44;", ",");
 				addItem( filename, name, duration );
 				name=""; 
 				duration = 0;
@@ -903,9 +946,10 @@ void Playlist::load_m3u(QString file, M3UFormat format) {
 		f.close();
 		//list();
 
+		setPlaylistFilename(file);
 		setModified( false );
 
-		startPlay();
+		if (start_play_on_load) startPlay();
 	}
 }
 
@@ -952,9 +996,10 @@ void Playlist::load_pls(QString file) {
 
 	//list();
 
+	setPlaylistFilename(file);
 	setModified( false );
 
-	if (set.status() == QSettings::NoError) startPlay();
+	if (set.status() == QSettings::NoError && start_play_on_load) startPlay();
 }
 
 void Playlist::loadXSPF(const QString & filename) {
@@ -994,8 +1039,9 @@ void Playlist::loadXSPF(const QString & filename) {
 		}
 
 		//list();
+		setPlaylistFilename(filename);
 		setModified( false );
-		startPlay();
+		if (start_play_on_load) startPlay();
 	}
 }
 
@@ -1023,6 +1069,7 @@ bool Playlist::save_m3u(QString file) {
 			stream.setCodec(QTextCodec::codecForLocale());
 
 		QString filename;
+		QString name;
 
 		stream << "#EXTM3U" << "\n";
 		stream << "# Playlist created by SMPlayer " << Version::printable() << " \n";
@@ -1033,9 +1080,11 @@ bool Playlist::save_m3u(QString file) {
 			#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 			filename = Helper::changeSlashes(filename);
 			#endif
+			name = i->name();
+			name.replace(",", "&#44;");
 			stream << "#EXTINF:";
 			stream << i->duration() << ",";
-			stream << i->name() << "\n";
+			stream << name << "\n";
 			// Try to save the filename as relative instead of absolute
 			if (filename.startsWith( dir_path )) {
 				filename = filename.mid( dir_path.length() );
@@ -1044,6 +1093,7 @@ bool Playlist::save_m3u(QString file) {
 		}
 		f.close();
 
+		setPlaylistFilename(file);
 		setModified( false );
 		return true;
 	} else {
@@ -1094,7 +1144,10 @@ bool Playlist::save_pls(QString file) {
 	set.sync();
 
 	bool ok = (set.status() == QSettings::NoError);
-	if (ok) setModified( false );
+	if (ok) {
+		setPlaylistFilename(file);
+		setModified( false );
+	}
 
 	return ok;
 }
@@ -1158,6 +1211,7 @@ bool Playlist::saveXSPF(const QString & filename) {
 		stream << "\t</trackList>\n";
 		stream << "</playlist>\n";
 
+		setPlaylistFilename(filename);
 		setModified(false);
 		return true;
 	} else {
@@ -1193,12 +1247,23 @@ void Playlist::load() {
 	}
 }
 
-bool Playlist::save() {
-	Extensions e;
-	QString s = MyFileDialog::getSaveFileName(
+bool Playlist::saveCurrentPlaylist() {
+	qDebug("Playlist::saveCurrentPlaylist");
+	return save(playlistFilename());
+}
+
+bool Playlist::save(const QString & filename) {
+	qDebug() << "Playlist::save:" << filename;
+
+	QString s = filename;
+
+	if (s.isEmpty()) {
+		Extensions e;
+		s = MyFileDialog::getSaveFileName(
                     this, tr("Choose a filename"), 
                     lastDir(),
                     tr("Playlists") + e.playlist().forFilter() + ";;" + tr("All files") +" (*)");
+	}
 
 	if (!s.isEmpty()) {
 		// If filename has no extension, add it
@@ -1340,6 +1405,14 @@ void Playlist::playPrev() {
 	}
 }
 
+void Playlist::playNextAuto() {
+	qDebug("Playlist::playNextAuto");
+	if (automatically_play_next) {
+		playNext();
+	} else {
+		emit playlistEnded();
+	}
+}
 
 void Playlist::resumePlay() {
 	qDebug("Playlist::resumePlay");
@@ -1414,7 +1487,10 @@ void Playlist::addFiles() {
                             tr("Multimedia") + e.multimedia().forFilter() + ";;" +
                             tr("All files") +" (*.*)" );
 
-	if (files.count()!=0) addFiles(files);  
+	if (files.count() != 0) {
+		addFiles(files);
+		setModified(true);
+	}
 }
 
 void Playlist::addFiles(QStringList files, AutoGetInfo auto_get_info) {
@@ -1492,6 +1568,7 @@ void Playlist::addUrls() {
 		foreach(QString u, urls) {
 			if (!u.isEmpty()) addItem( u, "", 0 );
 		}
+		setModified(true);
 	}
 }
 
@@ -1533,6 +1610,7 @@ void Playlist::addDirectory(QString dir) {
 			}
 		}
 	}
+	setModified(true);
 }
 
 // Remove selected items
@@ -1559,6 +1637,7 @@ void Playlist::removeSelected() {
 
 void Playlist::removeAll() {
 	clear();
+	setPlaylistFilename("");
 }
 
 void Playlist::clearPlayedTag() {
@@ -1614,6 +1693,8 @@ void Playlist::upItem() {
 		QList<QStandardItem*> cells = table->takeRow(row);
 		table->insertRow(s_prev.row(), cells);
 		listView->selectionModel()->setCurrentIndex(listView->model()->index(index.row()-1, 0), QItemSelectionModel::SelectCurrent | QItemSelectionModel::Rows);
+
+		setModified(true);
 	}
 }
 
@@ -1644,6 +1725,8 @@ void Playlist::downItem() {
 		QList<QStandardItem*> cells = table->takeRow(row);
 		table->insertRow(s_next.row(), cells);
 		listView->selectionModel()->setCurrentIndex(listView->model()->index(index.row()+1, 0), QItemSelectionModel::SelectCurrent | QItemSelectionModel::Rows);
+
+		setModified(true);
 	}
 }
 
@@ -1668,7 +1751,7 @@ void Playlist::editItem(int row) {
             tr("Type the name that will be displayed in the playlist for this file:"),
             QLineEdit::Normal,
             current_name, &ok );
-    if ( ok && !text.isEmpty() ) {
+	if ( ok && !text.isEmpty() ) {
 		// user entered something and pressed OK
 		i->setName(text);
 
@@ -1777,7 +1860,21 @@ void Playlist::dropEvent( QDropEvent *e ) {
 			only_files.append( files[n] );
 		}
 	}
+
+	if (only_files.count() == 1) {
+		// Check if the file is a playlist
+		QString filename = only_files[0];
+		QFileInfo fi(filename);
+		QString extension = fi.suffix().toLower();
+		if (extension == "m3u8" || extension == "m3u") { load_m3u(filename); return; }
+		else
+		if (extension == "pls") { load_pls(filename); return; }
+		else
+		if (extension == "xspf") { loadXSPF(filename); return; }
+	}
+
 	addFiles( only_files );
+	setModified(true);
 }
 
 
@@ -1829,6 +1926,7 @@ void Playlist::saveSettings() {
 	set->setValue( "recursive_add_directory", recursive_add_directory );
 	set->setValue( "save_playlist_in_config", save_playlist_in_config );
 	set->setValue( "play_files_from_start", play_files_from_start );
+	set->setValue( "start_play_on_load", start_play_on_load );
 	set->setValue( "automatically_play_next", automatically_play_next );
 	set->setValue( "ignore_player_errors", ignore_player_errors );
 	set->setValue( "change_name", change_name );
@@ -1843,9 +1941,10 @@ void Playlist::saveSettings() {
 
 	set->setValue( "sort_column", proxy->sortColumn() );
 	set->setValue( "sort_order", proxy->sortOrder() );
-	set->setValue( "filter_case_sensivity", proxy->filterCaseSensitivity() );
+	set->setValue( "filter_case_sensitive", filterCaseSensitive() );
 	set->setValue( "filter", filter_edit->text() );
-	set->setValue( "sort_case_sensivity", proxy->sortCaseSensitivity() );
+	set->setValue( "sort_case_sensitive", sortCaseSensitive() );
+	set->setValue( "auto_sort", autoSort() );
 
 	set->setValue( "show_search", showSearchAct->isChecked() );
 
@@ -1870,6 +1969,7 @@ void Playlist::saveSettings() {
 		}
 		set->endArray();
 		set->setValue( "current_item", findCurrentItem() );
+		set->setValue("filename", playlistFilename());
 		set->setValue( "modified", modified );
 
 		set->endGroup();
@@ -1883,6 +1983,8 @@ void Playlist::saveSettings() {
 #endif
 
 	if (set->contains("playlist/change_title")) set->remove("playlist/change_title");
+	if (set->contains("playlist/sort_case_sensivity")) set->remove("playlist/sort_case_sensivity");
+	if (set->contains("playlist/filter_case_sensivity")) set->remove("playlist/filter_case_sensivity");
 }
 
 void Playlist::loadSettings() {
@@ -1899,6 +2001,7 @@ void Playlist::loadSettings() {
 	recursive_add_directory = set->value( "recursive_add_directory", recursive_add_directory ).toBool();
 	save_playlist_in_config = set->value( "save_playlist_in_config", save_playlist_in_config ).toBool();
 	play_files_from_start = set->value( "play_files_from_start", play_files_from_start ).toBool();
+	start_play_on_load = set->value( "start_play_on_load", start_play_on_load ).toBool();
 	automatically_play_next = set->value( "automatically_play_next", automatically_play_next ).toBool();
 	ignore_player_errors = set->value( "ignore_player_errors", ignore_player_errors ).toBool();
 	change_name = set->value( "change_name", change_name ).toBool();
@@ -1913,9 +2016,10 @@ void Playlist::loadSettings() {
 
 	int sort_column = set->value("sort_column", COL_NUM).toInt();
 	int sort_order = set->value("sort_order", Qt::AscendingOrder).toInt();
-	int filter_case_sensivity = set->value("filter_case_sensivity", Qt::CaseInsensitive).toInt();
+	bool filter_case_sensitive = set->value("filter_case_sensitive", false).toBool();
 	QString filter = set->value( "filter").toString();
-	int sort_case_sensivity = set->value("sort_case_sensivity", Qt::CaseInsensitive).toInt();
+	bool sort_case_sensitive = set->value("sort_case_sensitive", false).toBool();
+	bool auto_sort = set->value("auto_sort", false).toBool();
 
 	showSearchAct->setChecked( set->value( "show_search", false).toBool() );
 
@@ -1944,6 +2048,7 @@ void Playlist::loadSettings() {
 		}
 		set->endArray();
 		setCurrentItem( set->value( "current_item", -1 ).toInt() );
+		setPlaylistFilename( set->value("filename", "").toString() );
 		setModified( set->value( "modified", false ).toBool() );
 
 		set->endGroup();
@@ -1957,10 +2062,11 @@ void Playlist::loadSettings() {
 	set->endGroup();
 #endif
 
-	proxy->setFilterCaseSensitivity( (Qt::CaseSensitivity) filter_case_sensivity);
-	proxy->setSortCaseSensitivity( (Qt::CaseSensitivity) sort_case_sensivity);
+	setFilterCaseSensitive(filter_case_sensitive);
+	setSortCaseSensitive(sort_case_sensitive);
 	proxy->sort(sort_column, (Qt::SortOrder) sort_order);
 	filter_edit->setText(filter);
+	setAutoSort(auto_sort);
 
 	if (!listView->isColumnHidden(COL_NUM)) showPositionColumnAct->setChecked(true);
 	if (!listView->isColumnHidden(COL_NAME)) showNameColumnAct->setChecked(true);
@@ -1987,7 +2093,32 @@ void Playlist::setDurationColumnVisible(bool b) {
 
 void Playlist::setFilenameColumnVisible(bool b) {
 	listView->setColumnHidden(COL_FILENAME, !b);
+}
 
+void Playlist::setAutoSort(bool b) {
+	proxy->setDynamicSortFilter(b);
+}
+
+bool Playlist::autoSort() {
+	return proxy->dynamicSortFilter();
+}
+
+void Playlist::setSortCaseSensitive(bool b) {
+	Qt::CaseSensitivity c = b ? Qt::CaseSensitive : Qt::CaseInsensitive;
+	proxy->setSortCaseSensitivity(c);
+}
+
+bool Playlist::sortCaseSensitive() {
+	return (proxy->sortCaseSensitivity() == Qt::CaseSensitive);
+}
+
+void Playlist::setFilterCaseSensitive(bool b) {
+	Qt::CaseSensitivity c = b ? Qt::CaseSensitive : Qt::CaseInsensitive;
+	proxy->setFilterCaseSensitivity(c);
+}
+
+bool Playlist::filterCaseSensitive() {
+	return (proxy->filterCaseSensitivity() == Qt::CaseSensitive);
 }
 
 #ifdef PLAYLIST_DOWNLOAD
@@ -2034,14 +2165,17 @@ void Playlist::playlistDownloaded(QByteArray data) {
 
 	if (data.contains("#EXTM3U")) {
 		load_m3u(tfile, M3U8);
+		setPlaylistFilename("");
 	}
 	else
 	if (data.contains("[playlist]")) {
 		load_pls(tfile);
+		setPlaylistFilename("");
 	}
 	else
 	if (data.contains("xspf.org")) {
 		loadXSPF(tfile);
+		setPlaylistFilename("");
 	}
 	else {
 		QMessageBox::warning(this, "SMPlayer", tr("It's not possible to load this playlist") +": "+ tr("Unrecognized format."));
