@@ -102,7 +102,10 @@ public:
 	bool use_soft_video_eq;
 	bool use_slices;
 	int autoq; 	//!< Postprocessing quality
+
+#ifdef ADD_BLACKBORDERS_FS
 	bool add_blackborders_on_fullscreen;
+#endif
 
 #ifdef Q_OS_WIN
 	#ifdef SCREENSAVER_OFF
@@ -341,6 +344,13 @@ public:
 	bool use_mpris2;
 #endif
 
+#ifdef MPV_SUPPORT
+	QString mpv_osd_media_info;
+#endif
+#ifdef MPLAYER_SUPPORT
+	QString mplayer_osd_media_info;
+#endif
+
 
 	/* *********
 	   GUI stuff
@@ -519,6 +529,10 @@ public:
 	//! 100 = 100% at the bottom
 	int initial_sub_pos;
 
+#ifndef ADD_BLACKBORDERS_FS
+	bool initial_blackborders;
+#endif
+
 	bool initial_postprocessing; //!< global postprocessing filter
 	bool initial_volnorm;
 
