@@ -36,10 +36,10 @@ public:
 	virtual QPixmap sectionIcon();
 
     // Pass data to the dialog
-    void setData(Preferences * pref);
+	void setData(Preferences * pref);
 
     // Apply changes
-    void getData(Preferences * pref);
+	void getData(Preferences * pref);
 
 
 	void setDirectoryRecursion(bool b);
@@ -54,9 +54,21 @@ public:
 	void setPlayFilesFromStart(bool b);
 	bool playFilesFromStart();
 
+	void setPlayOnLoad(bool b);
+	bool playOnLoad();
+
+	void setPlayNextAutomatically(bool b);
+	bool playNextAutomatically();
+
 	void setIgnorePlayerErrors(bool b);
 	bool ignorePlayerErrors();
 
+	void setAutoSort(bool b);
+	bool autoSort();
+
+	void setFilterCaseSensitive(bool b);
+	bool filterCaseSensitive();
+
 protected:
 	virtual void createHelp();
 
