@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,13 +16,13 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/*! 
+/*!
 	This class is to replace some QCheckBox with a combo with three possible
     values: true, false or autodetect
 */
 
-#ifndef _TRISTATE_COMBO_H_
-#define _TRISTATE_COMBO_H_
+#ifndef TRISTATE_COMBO_H
+#define TRISTATE_COMBO_H
 
 #include <QComboBox>
 #include "preferences.h"
