@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#ifndef _TVLIST_H_
-#define _TVLIST_H_
+#ifndef TVLIST_H
+#define TVLIST_H
 
 #include "favorites.h"
 
@@ -34,6 +34,10 @@ public:
 	TVList(bool check_channels_conf, Services services, QString filename, QWidget * parent = 0);
 	~TVList();
 
+#ifndef Q_OS_WIN
+	static QString findChannelsFile();
+#endif
+
 #ifndef Q_OS_WIN
 protected:
 	void parse_channels_conf(Services services);
