@@ -20,6 +20,7 @@
 #include "mediasettings.h"
 #include <QSettings>
 #include <QFileInfo>
+#include <QDebug>
 
 TVSettings::TVSettings(QString directory) : FileSettingsBase(directory) 
 {
@@ -41,12 +42,12 @@ QString TVSettings::filenameToGroupname(const QString & filename) {
 	return s;
 }
 
-bool TVSettings::existSettingsFor(QString filename) {
-	qDebug("TVSettings::existSettingsFor: '%s'", filename.toUtf8().constData());
+bool TVSettings::existSettingsFor(QString filename, int type) {
+	qDebug() << "TVSettings::existSettingsFor:" << filename;
 
 	QString group_name = filenameToGroupname(filename);
 
-	qDebug("TVSettings::existSettingsFor: group_name: '%s'", group_name.toUtf8().constData());
+	qDebug() << "TVSettings::existSettingsFor: group_name:'" << group_name;
 
 	my_settings->beginGroup( group_name );
 	bool saved = my_settings->value("saved", false).toBool();
@@ -55,12 +56,12 @@ bool TVSettings::existSettingsFor(QString filename) {
 	return saved;
 }
 
-void TVSettings::loadSettingsFor(QString filename, MediaSettings & mset, int player) {
-	qDebug("TVSettings::loadSettingsFor: '%s'", filename.toUtf8().constData());
+void TVSettings::loadSettingsFor(QString filename, int type, MediaSettings & mset, int player) {
+	qDebug() << "TVSettings::loadSettingsFor:" << filename;
 
 	QString group_name = filenameToGroupname(filename);
 
-	qDebug("TVSettings::loadSettingsFor: group_name: '%s'", group_name.toUtf8().constData());
+	qDebug() << "TVSettings::loadSettingsFor: group_name:" << group_name;
 
 	mset.reset();
 
@@ -69,12 +70,12 @@ void TVSettings::loadSettingsFor(QString filename, MediaSettings & mset, int pla
 	my_settings->endGroup();
 }
 
-void TVSettings::saveSettingsFor(QString filename, MediaSettings & mset, int player) {
-	qDebug("TVSettings::saveSettingsFor: '%s'", filename.toUtf8().constData());
+void TVSettings::saveSettingsFor(QString filename, int type, MediaSettings & mset, int player) {
+	qDebug() << "TVSettings::saveSettingsFor" << filename;
 
 	QString group_name = filenameToGroupname(filename);
 
-	qDebug("TVSettings::saveSettingsFor: group_name: '%s'", group_name.toUtf8().constData());
+	qDebug() << "TVSettings::saveSettingsFor: group_name:" << group_name;
 
 	my_settings->beginGroup( group_name );
 	my_settings->setValue("saved", true);
