@@ -29,11 +29,11 @@ public:
 	TVSettings(QString directory);
 	virtual ~TVSettings();
 
-	virtual bool existSettingsFor(QString filename);
+	virtual bool existSettingsFor(QString filename, int type);
 
-	virtual void loadSettingsFor(QString filename, MediaSettings & mset, int player);
+	virtual void loadSettingsFor(QString filename, int type, MediaSettings & mset, int player);
 
-	virtual void saveSettingsFor(QString filename, MediaSettings & mset, int player);
+	virtual void saveSettingsFor(QString filename, int type, MediaSettings & mset, int player);
 
 	static QString filenameToGroupname(const QString & filename);
 
